@@ -11,6 +11,7 @@
 #' @param locationid A valid location id or a vector or list of location ids.
 #' @return A list containing metadata and the data, or a single data.frame.
 #' @family ncdc
+#' @references https://www.ncdc.noaa.gov/cdo-web/webservices/v2
 #' @examples \dontrun{
 #' # All locations, first 25 results
 #' ncdc_locs()
@@ -65,7 +66,7 @@ ncdc_locs <- function(datasetid=NULL, locationid=NULL, locationcategoryid=NULL,
       dat <- data.frame(tt, stringsAsFactors=FALSE)
       all <- list(meta=NULL, data=dat)
     } else {
-      if (class(try(tt$results, silent = TRUE)) == "try-error"){
+      if (inherits(try(tt$results, silent = TRUE), "try-error")){
         all <- list(meta = NULL, data = NULL)
         warning("Sorry, no data found")
       } else {
